31.102: EF.EST enables/disables services; name commands accordingly

EF.EST is the *enabled* services table.  Let's call the shell commands
enable and disable, rather than activate/deactivate.

Change-Id: Iacbdab42bc08e2be38ad7233d903fa7cda0d95b6
diff --git a/pySim/ts_31_102.py b/pySim/ts_31_102.py
index 3edc6e3..dc2a4d8 100644
--- a/pySim/ts_31_102.py
+++ b/pySim/ts_31_102.py
@@ -749,12 +749,12 @@
         def __init__(self):
             super().__init__()
 
-        def do_est_service_activate(self, arg):
-            """Activate a service within EF.UST"""
+        def do_est_service_enable(self, arg):
+            """Enable a service within EF.UST"""
             self._cmd.card.update_est(int(arg), 1)
 
-        def do_est_service_deactivate(self, arg):
-            """Deactivate a service within EF.UST"""
+        def do_est_service_disable(self, arg):
+            """Disable a service within EF.UST"""
             self._cmd.card.update_est(int(arg), 0)
 
 # TS 31.102 Section 4.2.48